from ..types.ChatPermissions import ChatPermissions
from .BaseMethod import BaseMethod

class setChatPermissions(BaseMethod):
    '''
    Use this method to set default chat permissions for all members. The bot must be an administrator in the group or a supergroup for this to work and must have the can_restrict_members administrator rights. Returns True on success.
    :param chat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
    :type chat_id: int
    :param permissions: A JSON-serialized object for new default chat permissions
    :type permissions: ChatPermissions
    :param use_independent_chat_permissions: Pass True if chat permissions are set independently. Otherwise, the can_send_other_messages and can_add_web_page_previews permissions will imply the can_send_messages, can_send_audios, can_send_documents, can_send_photos, can_send_videos, can_send_video_notes, and can_send_voice_notes permissions; the can_send_polls permission will imply the can_send_messages permission.
    :type use_independent_chat_permissions: bool = False
    :return: {tdesc}

    '''

    async def __call__(self,
    permissions: ChatPermissions,
    chat_id: int |str,
    use_independent_chat_permissions: bool = False,
    ) -> bool:
        '''
        :param chat_id: Unique identifier for the target chat or username of the target supergroup (in the format @supergroupusername)
        :type chat_id: int
        :param permissions: A JSON-serialized object for new default chat permissions
        :type permissions: ChatPermissions
        :param use_independent_chat_permissions: Pass True if chat permissions are set independently. Otherwise, the can_send_other_messages and can_add_web_page_previews permissions will imply the can_send_messages, can_send_audios, can_send_documents, can_send_photos, can_send_videos, can_send_video_notes, and can_send_voice_notes permissions; the can_send_polls permission will imply the can_send_messages permission.
        :type use_independent_chat_permissions: bool = False
        '''
        return await self.request(
            chat_id=chat_id,
            permissions=permissions,
            use_independent_chat_permissions=use_independent_chat_permissions,
        )
